@@ -34,7 +34,7 @@ install.completion = function (opts, cb) {
   // if it starts with https?://, then just give up, because it's a url
   // for now, not yet implemented.
   var registry = npm.registry
-    , uri = url.resolve(npm.config.get("registry"), "/-/short")
+    , uri = url.resolve(npm.config.get("registry"), "-/short")
   registry.get(uri, null, function (er, pkgs) {
     if (er) return cb()
     if (!opts.partialWord) return cb(null, pkgs)
